#ifndef ANIMACAO
    #define ANIMACAO
    
#ifndef ALLEGRO
    #define ALLEGRO
    #include <allegro.h>
#endif

class ParFigura{
public:
    BITMAP *figuraDireita;
    BITMAP *figuraEsquerda;
    
    ParFigura(char *figuraDireita){
        this->figuraDireita = load_bitmap(figuraDireita,NULL);
        this->figuraEsquerda = create_bitmap(this->figuraDireita->w,this->figuraDireita->h);
        clear_to_color(this->figuraEsquerda, PIXEL_TRANSP); 
        draw_sprite_h_flip(this->figuraEsquerda,this->figuraDireita,0,0);
    }
    ~ParFigura(){
        destroy_bitmap(figuraDireita);
        destroy_bitmap(figuraEsquerda);
    }    
};
class Animacao{
public:
    int quantidade;
    int espacamento;
    int altura;
    BITMAP *figura_direita;
    BITMAP *figura_esquerda;
    int ponteiro;
    int corrImprX;
    int corrImprY;
};
class AnimacaoAndar : Animacao{
public:
    
    int inicCorrida;    
    
    AnimacaoAndar(int quantidade,int inicCorrida,ParFigura *par,int corrImprX, int corrImprY){
        this->quantidade = quantidade;
        this->figura_direita = par->figuraDireita;
        this->figura_esquerda = par->figuraEsquerda;
        this->ponteiro = 0;
        this->espacamento = (this->figura_direita->w)/this->quantidade;
        this->altura = this->figura_direita->h;
        this->inicCorrida = inicCorrida;
        this->corrImprX = corrImprX;
        this->corrImprY = corrImprY;
    }
    ~AnimacaoAndar(){
    }
    int getPonteiro(){
       return this->ponteiro;
    }
    int getCorrImprX(){
        return this->corrImprX;
    }
    int getCorrImprY(){
        return this->corrImprY;
    }
    void andar(int x, int y,bool travado,bool direita){
    x += this->corrImprX;
    y += this->corrImprY;
        if(direita)
            moverDir(x,y,travado);
        else
            moverEsq(x,y,travado);
    }
    
    void moverDir(int x, int y,bool travado){
       
        if(!travado)        
                this->ponteiro = 0;
                
        masked_blit(this->figura_direita,buffer, this->ponteiro*this->espacamento,0, x, y,
                espacamento, this->altura);
        this->ponteiro++;
        if(this->ponteiro == this->quantidade)
                this->ponteiro = this->inicCorrida;        
    }
    
    void moverEsq(int x, int y,bool travado){
        if(!travado){        
                this->ponteiro = this->quantidade-1;
        }
        masked_blit(this->figura_esquerda, buffer,this->ponteiro*this->espacamento,0, x, y,
                espacamento, this->altura);
        this->ponteiro--;
        if(this->ponteiro == - 1)
                this->ponteiro = this->quantidade - this->inicCorrida - 1;
    }           
};
class AnimacaoPular : Animacao{
public:
    
    AnimacaoPular(int quantidade, ParFigura *par,int corrImprX, int corrImprY){
        this->quantidade = quantidade;
        this->figura_direita = par->figuraDireita;
        this->figura_esquerda = par->figuraEsquerda;
        this->ponteiro = 0;
        this->espacamento = (this->figura_direita->w)/this->quantidade;
        this->altura = this->figura_direita->h;        
        this->corrImprX = corrImprX;
        this->corrImprY = corrImprY;
    }
    ~AnimacaoPular(){
    }
    int getPonteiro(){
       return this->ponteiro;
    }
    int getCorrImprX(){
        return this->corrImprX;
    }
    int getCorrImprY(){
        return this->corrImprY;
    }    
    void pular(int x, int y, bool travado, bool direita){
       x += this->corrImprX;
       y += this->corrImprY;
       if(!travado)
           this->ponteiro = 0;
      
       if(direita)
           masked_blit(this->figura_direita,buffer, this->ponteiro*this->espacamento,0, x, y, espacamento, this->altura);
       else
           masked_blit(this->figura_esquerda,buffer,(this->quantidade-this->ponteiro -1)*this->espacamento,0, x, y, espacamento, this->altura);
              
       if(this->ponteiro < this->quantidade-1)
           this->ponteiro++;  
    }
};
class AnimacaoAtirar : Animacao{
public:
    int retomada;
    
    AnimacaoAtirar(int quantidade, int retomada,ParFigura *par,int corrImprX, int corrImprY){
        this->quantidade = quantidade;
        this->figura_direita = par->figuraDireita;
        this->figura_esquerda = par->figuraEsquerda;
        this->ponteiro = 0;
        this->espacamento = (this->figura_direita->w)/this->quantidade;
        this->altura = this->figura_direita->h;        
        this->retomada = retomada;
        this->corrImprX = corrImprX;
        this->corrImprY = corrImprY;
    }
    ~AnimacaoAtirar(){
    }
    int getPonteiro(){
       return this->ponteiro;
    }
    int getCorrImprX(){
        return this->corrImprX;
    }
    int getCorrImprY(){
        return this->corrImprY;
    }    
    bool atirar(int x, int y, bool travado, bool direita){  //retorna um booleano indicando se terminou a animacao
       x += this->corrImprX;
       y += this->corrImprY;
       if(!travado)
           this->ponteiro = 0;
       
       if(direita)
           masked_blit(this->figura_direita,buffer, this->ponteiro*this->espacamento,0, x, y, espacamento, this->altura);
       else
           masked_blit(this->figura_esquerda,buffer,(this->quantidade-this->ponteiro -1)*this->espacamento,0, x, y, espacamento, this->altura);       
       this->ponteiro++;
       if(this->ponteiro == this->quantidade){
           this->ponteiro = this->retomada;  
           return true;
       }
       return false;
    }
};               
class AnimacaoRotina : Animacao{
public:
    int pausa;
    int aux;
    
    AnimacaoRotina(int quantidade, int pausa, ParFigura *par,int corrImprX, int corrImprY){
        this->quantidade = quantidade;
        this->figura_direita = par->figuraDireita;
        this->figura_esquerda = par->figuraEsquerda;
        this->ponteiro = 0;
        this->espacamento = (this->figura_direita->w)/this->quantidade;
        this->altura = this->figura_direita->h;                
        this->pausa = pausa;
        this->aux = 0;
        this->corrImprX = corrImprX;
        this->corrImprY = corrImprY;
        
    }
    ~AnimacaoRotina(){        
    }
    int getPonteiro(){
       return this->ponteiro;
    }
    int getCorrImprX(){
        return this->corrImprX;
    }
    int getCorrImprY(){
        return this->corrImprY;
    }
    bool play(int x, int y, bool travado, bool direita){  //retorna um booleano indicando se terminou a animacao
       x += this->corrImprX;
       y += this->corrImprY;
       if(!travado)
           this->ponteiro = 0;
           
       if(direita)
           masked_blit(this->figura_direita,buffer, this->ponteiro*this->espacamento,0, x, y, espacamento, this->altura);
       else
           masked_blit(this->figura_esquerda,buffer,(this->quantidade-this->ponteiro -1)*this->espacamento,0, x, y, espacamento, this->altura);       
       
       this->aux++;
       if(this->aux == this->pausa){
           this->ponteiro++;
           this->aux = 0;
       }
       if(this->ponteiro == this->quantidade){
           this->ponteiro = 0;  
           return true;
       }
       return false;
    }
};
class AnimacaoRotina2 : Animacao{
public:
    int posRetorno;
    int pausa;
    int aux;
    
    AnimacaoRotina2(int quantidade,int posRetorno, int repeticoes,ParFigura *par,int corrImprX, int corrImprY){
        this->quantidade = quantidade;
        this->figura_direita = par->figuraDireita;
        this->figura_esquerda = par->figuraEsquerda;
        this->ponteiro = 0;
        this->posRetorno = posRetorno;
        this->espacamento = (this->figura_direita->w)/this->quantidade;
        this->altura = this->figura_direita->h;                
        this->pausa = repeticoes;
        this->aux = 0;
        this->corrImprX = corrImprX;
        this->corrImprY = corrImprY;
        
    }
    ~AnimacaoRotina2(){
    }
    int getPonteiro(){
       return this->ponteiro;
    }
    int getCorrImprX(){
        return this->corrImprX;
    }
    int getCorrImprY(){
        return this->corrImprY;
    }
    bool play(int x, int y,int ponteiro, bool travado, bool direita){  //retorna um booleano indicando se terminou a animacao
       x += this->corrImprX;
       y += this->corrImprY;
       if(!travado){
           this->ponteiro = 0;
           this->ponteiro += ponteiro;
       }
       if(direita)
           masked_blit(this->figura_direita,buffer, this->ponteiro*this->espacamento,0, x, y, espacamento, this->altura);
       else
           masked_blit(this->figura_esquerda,buffer,(this->quantidade-this->ponteiro -1)*this->espacamento,0, x, y, espacamento, this->altura);       
       
       this->aux++;
       if(this->aux==this->pausa || this->ponteiro<this->posRetorno){
           this->ponteiro++;
           this->aux = 0;
       }
       if(this->ponteiro == this->quantidade){
           this->ponteiro = this->posRetorno;  
           return true;
       }
       return false;
    }
};
#endif
