#ifndef AUTONOMOS
    #define AUTONOMOS

#include "animacao.h"
#include "cenario.h"
#ifndef ALLEGRO
    #define ALLEGRO
    #include <allegro.h>
#endif
#include "mover.h"
#include "colisao.h"

enum tipo_autonomo {COLISAO_BALA,CAMINHAO,REFEM,INIMIGO_ATIRADOR,INIMIGO_ESCUDO,BOMBA_PRINCIPAL,COLISAO_BOMBA,PASSARINHO};
class Autonomos{
public:
    int posicaoX;
    int posicaoY; 
    int marcador;
    virtual bool play() = 0; 
    enum tipo_autonomo tipo;  
    Animacao *animacaoAtiva; 
    
    int getPosAtqX(){
        return (this->posicaoX + this->animacaoAtiva->corrImprX);
    }
    int getPosAtqY(){
        return (this->posicaoY + this->animacaoAtiva->corrImprY);
    }
};
class ColisaoBomba : Autonomos{
public:
    AnimacaoRotina *colisao;
    
    ColisaoBomba(int posicaoX,int posicaoY,ParFigura *figura){
        this->colisao = new AnimacaoRotina(25,1,figura,-18,-100);
        this->posicaoX = posicaoX;
        this->posicaoY = posicaoY;                
        this->tipo = COLISAO_BOMBA;
    }
    ~ColisaoBomba(){
        delete(colisao);
    }
    bool play(){
        return this->colisao->play(posicaoX,posicaoY,true,true);
    }
};
enum estados_bomba {BOMBA_ESPERANDO,PRIMEIRO_PULO,SEGUNDO_PULO};
class BombaPrincipal : Autonomos{
public:
    Mover *movimento;
    AnimacaoRotina *parabola1,*parabola2;
    bool pulando;
    int contadorMov;
    enum estados_bomba estado;
    bool direita;
    ParFigura *colisBomba;
    
    BombaPrincipal(int posicaoX,int posicaoY,bool direita,ParFigura *figura1,ParFigura *figura2,ParFigura *colisBomba){
        this->movimento = new Mover(cenario,3,18,0,19,&this->pulando); 
        this->parabola1 = new AnimacaoRotina(14,1,figura1,0,0);
        this->parabola2 = new AnimacaoRotina(12,1,figura2,0,0);
        this->colisBomba = colisBomba;
        this->posicaoX = posicaoX;
        this->posicaoY = posicaoY;
        this->direita = direita;
        this->contadorMov = 0;                
        this->tipo = BOMBA_PRINCIPAL;
        this->estado = BOMBA_ESPERANDO;
        this->pulando = false;        
    }
    ~BombaPrincipal(){
        delete(this->movimento);
        delete(this->parabola1);
        delete(this->parabola2);
    }    
    bool play(){
        int aux;
        this->movimento->pulando(&this->posicaoX,&this->posicaoY);
        switch(this->estado){
            case BOMBA_ESPERANDO:
                if(this->contadorMov++>3){
                    this->estado = PRIMEIRO_PULO;
                    this->movimento->pular(&this->posicaoX,&this->posicaoY,-10);                
                }
                break;
            case PRIMEIRO_PULO:
                this->parabola1->play(posicaoX,posicaoY,true,this->direita);
                aux = this->posicaoX;
                if(this->direita)
                    this->movimento->moverDireita(&this->posicaoX,&this->posicaoY);
                else
                    this->movimento->moverEsquerda(&this->posicaoX,&this->posicaoY);
                if(aux==this->posicaoX)
                    return true;                        
                if(!this->pulando){
                    this->estado = SEGUNDO_PULO;
                    this->movimento->pular(&this->posicaoX,&this->posicaoY,-8);                
                }
                break;
            case SEGUNDO_PULO:
                this->parabola2->play(posicaoX,posicaoY,true,this->direita);
                aux = this->posicaoX;
                if(this->direita)
                    this->movimento->moverDireita(&this->posicaoX,&this->posicaoY);
                else
                    this->movimento->moverEsquerda(&this->posicaoX,&this->posicaoY);
                if(aux==this->posicaoX)
                    return true;                                                               
                if(!this->pulando){
                    return true;
                }                
                break;
        }        
        return false;
    }
};
class ColisaoBA : Autonomos{  
public:
    AnimacaoRotina *colisao;
    
    ColisaoBA(int posicaoX,int posicaoY,ParFigura *figura){
        this->colisao = new AnimacaoRotina(10,1,figura,-5,-25);
        this->posicaoX = posicaoX;
        this->posicaoY = posicaoY;                
        this->tipo = COLISAO_BALA;
    }
    ~ColisaoBA(){
        delete(colisao);
    }
    bool play(){
        return this->colisao->play(posicaoX,posicaoY,true,true);
    }
};
class ObjetoSimples : Autonomos{  
public:
    AnimacaoRotina *caminhao;
    bool direita;
    
    ObjetoSimples(int posicaoX,int posicaoY,ParFigura *figura,int quant,bool direita){
        this->caminhao = new AnimacaoRotina(quant,4,figura,-9,-30);
        this->posicaoX = posicaoX;
        this->posicaoY = posicaoY;        
        this->tipo = CAMINHAO;
        this->direita = direita;
    }
    ~ObjetoSimples(){
        free(caminhao);
    }
    bool play(){
        this->caminhao->play(posicaoX,posicaoY,true,this->direita);
        return false;
    }
};
class Refem : Autonomos{
public:
    AnimacaoRotina *andar;
    Mover *movimento;
    bool pulando;
    int contadorMov;
    bool direita;
    
    Refem(int posicaoX,int posicaoY,ParFigura *figura){
        this->posicaoX = posicaoX;
        this->posicaoY = posicaoY;        
        this->andar = new AnimacaoRotina(11,3,figura,0,0);
        this->movimento = new Mover(cenario,2,figura->figuraDireita->h,10,15,&(this->pulando));
        this->contadorMov = 0;
        this->direita = true;
        this->pulando = true;        
        this->tipo = REFEM;
    }
    bool play(){
        if(this->direita){
            this->movimento->pulando(&(this->posicaoX),&(this->posicaoY));
            this->movimento->moverDireita(&(this->posicaoX),&(this->posicaoY));
            this->andar->play(this->posicaoX,this->posicaoY,true,this->direita);
        }else{
            this->movimento->pulando(&(this->posicaoX),&(this->posicaoY));
            this->movimento->moverEsquerda(&(this->posicaoX),&(this->posicaoY));
            this->andar->play(this->posicaoX,this->posicaoY,true,this->direita);
        }   
        if(this->contadorMov++ > 50){
            this->direita = !this->direita;    
            this->contadorMov = 0;
        }
        return false;
    }
};
class Passarinho : Autonomos{
public:
    AnimacaoRotina *voar;
    
    Passarinho(int posicaoX,int posicaoY,ParFigura *figura){
        this->voar = new AnimacaoRotina(10,5,figura,0,0);
        this->posicaoX = posicaoX;
        this->posicaoY = posicaoY;                
        this->tipo = PASSARINHO;        
    }
    ~Passarinho(){
        delete(this->voar);
    }
    bool play(){
        this->posicaoX -= 3;
        this->voar->play(this->posicaoX,this->posicaoY,true,true);
        return false;
    }
};
class Bala{
public:
    AnimacaoRotina *figura;
    int velocMovX;
    int velocMovY;
    int posicaoX;
    int posicaoY;
    Cenario *cenario;
    ParFigura *colisBA;
    int marcador;
    
    Bala(int posicaoX,int posicaoY,int vX,int vY,ParFigura *figuras,int quant,ParFigura *colisBA,Cenario *cenario){
        this->posicaoX = posicaoX;
        this->posicaoY = posicaoY;
        this->figura = new AnimacaoRotina(quant,1,figuras,0,0);
        this->velocMovX = vX;
        this->velocMovY = vY;
        this->cenario = cenario;
        this->colisBA = colisBA;
    }
    ~Bala(){
        delete(this->figura);
    }
    int getPosAtqX(){
        return this->posicaoX + this->figura->getCorrImprX()+4;        
    }
    int getPosAtqY(){
        return this->posicaoY + this->figura->getCorrImprY()+3;        
    }
    bool imprimirBala(){
        this->figura->play(this->posicaoX,this->posicaoY,true,true);            
        return true;
    }
    bool mover(){        
        if(getpixel(this->cenario->cenario_restricoes,this->posicaoX+this->velocMovX,this->posicaoY+this->velocMovY)==PIXEL_TRANSP){
            this->posicaoX += this->velocMovX;
            this->posicaoY += this->velocMovY;                        
            return false;
        }else{
            for(int i=(velocMovX!=0?velocMovX:velocMovY);i>=0;i--){
                if(getpixel(this->cenario->cenario_restricoes,this->posicaoX+(velocMovX!=0?i:0),this->posicaoY+(velocMovY!=0?i:0))==PIXEL_TRANSP){
                    (this->velocMovX!=0?this->posicaoX:this->posicaoY)+=i;
                    return true;
                }
            }
            return true;            
        }
    }
};
enum estados_inimigo_escudo {parado_c_escudo,tirando_escudo,atirando,colocando_escudo,escudo_morto};
class InimigoEscudo : Autonomos{
public:
    Mover *movimento;
    bool pulando;    
    AnimacaoRotina *atirar;
    AnimacaoRotina *parado;
    AnimacaoRotina *tirandoEscudo;
    AnimacaoRotina *colocandoEscudo;
    AnimacaoRotina *morrendo;
    enum estados_inimigo_escudo estado;
    bool direita;
    bool morreu;
    
    InimigoEscudo(int posicaoX,int posicaoY,ParFigura* atirando,ParFigura* parado,
                   ParFigura* tirandoEscudo,ParFigura* colocandoEscudo,ParFigura* morrendo){
        this->movimento = new Mover(cenario,3,45,10,15,&this->pulando);
        this->pulando = true;
        this->posicaoX = posicaoX;
        this->posicaoY = posicaoY;
        this->atirar = new AnimacaoRotina(8,1,atirando,0,0);
        this->parado = new AnimacaoRotina(6,2,parado,0,0);
        this->tirandoEscudo = new AnimacaoRotina(6,2,tirandoEscudo,0,0);
        this->colocandoEscudo = new AnimacaoRotina(4,2,colocandoEscudo,0,0);
        this->morrendo = new AnimacaoRotina(14,1,morrendo,22,-7);
        this->estado = parado_c_escudo;
        this->direita = true;
        this->morreu = false;
        this->tipo = INIMIGO_ESCUDO;
        this->animacaoAtiva = (Animacao*)this->atirar;
    }
    ~InimigoEscudo(){
        delete(this->atirar);
        delete(this->parado);
        delete(this->tirandoEscudo);
        delete(this->colocandoEscudo);
    }
    bool play(){
        this->direita = (posX < this->posicaoX);
    
        this->movimento->pulando(&this->posicaoX,&this->posicaoY);
        switch(this->estado){
            case parado_c_escudo:
                this->morreu = false;
                this->animacaoAtiva = (Animacao*)this->parado;                        
                if(this->parado->play(this->posicaoX,this->posicaoY,true,this->direita)){
                    switch(rand()%3){ 
                        case 1:
                            this->estado = tirando_escudo;
                            break;                        
                    }
                }
                break;
            case tirando_escudo:
                this->morreu = false;
                this->animacaoAtiva = (Animacao*)this->tirandoEscudo;
                if(this->tirandoEscudo->play(this->posicaoX,this->posicaoY,true,this->direita))
                    this->estado = atirando;
                break;
            case colocando_escudo:
                if(this->morreu){
                    morrer:
                    this->animacaoAtiva = (Animacao*)this->morrendo;
                    this->direita = !this->direita;
                    this->estado = escudo_morto;
                    this->morrendo->play(this->posicaoX,this->posicaoY,true,this->direita);
                    break;
                }    
                this->animacaoAtiva = (Animacao*)this->colocandoEscudo;
                if(this->colocandoEscudo->play(this->posicaoX,this->posicaoY,true,this->direita))
                    this->estado = parado_c_escudo;                                                               
                break;
            case atirando:
                if(this->morreu)
                    goto morrer;
            
                this->animacaoAtiva = (Animacao*)this->atirar;
                if(this->atirar->play(this->posicaoX,this->posicaoY,true,this->direita)){
                    switch(rand()%3){ 
                        case 0:
                            this->estado = colocando_escudo;
                            break;                        
                    }
                }else if(this->atirar->getPonteiro()==1)
                    return true;
                break;
            case escudo_morto:
                this->animacaoAtiva = (Animacao*)this->morrendo;
                return this->morrendo->play(this->posicaoX,this->posicaoY,true,this->direita);
                break;
        }
        return false;
    }
};
enum estados_inimigo_atirador {PARADO_ini,ATIRAR_ini,MORTO_ini};
class InimigoAtirador : Autonomos{
public:
    Mover *movimento;
    bool pulando;    
    AnimacaoRotina *atirar;
    AnimacaoRotina *parado;
    AnimacaoRotina *morrendo;
    enum estados_inimigo_atirador estado;
    bool direita;
    bool morreu;
    
    InimigoAtirador(int posicaoX,int posicaoY,ParFigura* atirando,ParFigura* parado,ParFigura* morreu){
        this->movimento = new Mover(cenario,3,40,50,10,&this->pulando);
        this->pulando = true;
        this->posicaoX = posicaoX;
        this->posicaoY = posicaoY;
        this->atirar = new AnimacaoRotina(17,1,atirando,0,0);
        this->parado = new AnimacaoRotina(3,3,parado,0,0);
        this->morrendo = new AnimacaoRotina(14,1,morreu,22,-7);
        this->estado = PARADO_ini;
        this->direita = false;
        this->morreu = false;
        this->tipo = INIMIGO_ATIRADOR;
        this->animacaoAtiva = (Animacao*)this->atirar;
    }
    ~InimigoAtirador(){
        delete(this->atirar);
        delete(this->parado);
        delete(this->morrendo);
    }   
    bool play(){
        this->direita = (posX > this->posicaoX);
        
        this->movimento->pulando(&this->posicaoX,&this->posicaoY);
        switch(this->estado){
            case PARADO_ini:
                if(this->morreu){
                    this->estado = MORTO_ini;
                    this->morrendo->play(this->posicaoX,this->posicaoY,true,!this->direita);
                    break;
                }
                this->animacaoAtiva = (Animacao*)this->parado;
                if(this->parado->play(this->posicaoX,this->posicaoY,true,this->direita)){
                    switch(rand()%3){ 
                        case 0:
                            this->estado = ATIRAR_ini;
                            break;                        
                    }                    
                }
                break;
            case ATIRAR_ini:
                if(this->morreu){
                    this->estado = MORTO_ini;
                    this->morrendo->play(this->posicaoX,this->posicaoY,true,!this->direita);
                    break;
                }
                this->animacaoAtiva = (Animacao*)this->atirar;
                if(this->atirar->play(this->posicaoX,this->posicaoY,true,this->direita)){
                    switch(rand()%3){ 
                        case 0:
                            this->estado = PARADO_ini;
                            break;                        
                        case 1:
                            this->estado = PARADO_ini;
                            break;                        
                    }                    
                }else if(this->atirar->getPonteiro()==3)
                    return true;
                break;
            case MORTO_ini:
                
                return this->morrendo->play(this->posicaoX,this->posicaoY,true,!this->direita);
                break;
        }
        return false;
    }
};
struct InimigosStagio{  
    ParFigura *refem;
    Refem *refemCaminhando;
    
    ParFigura *caminhao;
    ObjetoSimples *caminhaoBand;
    
    ParFigura *passaro;
    Passarinho *passaro1;
    Passarinho *passaro2;
    Passarinho *passaro3;
    Passarinho *passaro4;
        
    ParFigura *inimigoAtirador;
    ParFigura *inimigoAtiradorParado;
    ParFigura *morrendo;
    InimigoAtirador *inimigo1;    
    InimigoAtirador *inimigo2; 
    InimigoAtirador *inimigo3; 
    InimigoAtirador *inimigo4; 
    InimigoAtirador *inimigo5; 
    InimigoAtirador *inimigo6;    
    InimigoAtirador *inimigo7; 
    InimigoAtirador *inimigo8; 
    InimigoAtirador *inimigo9; 
    InimigoAtirador *inimigo10; 
    
    ParFigura *incinerado;   
    
    ParFigura *figuraBala;
    ParFigura *figuraColBala;
    
    ParFigura *inimigo2atirando;
    ParFigura *inimigo2parado;
    ParFigura *inimigo2tiranEsc;
    ParFigura *inimigo2botanEsc;
    InimigoEscudo *inimigoEscudo1;
    InimigoEscudo *inimigoEscudo2;
    InimigoEscudo *inimigoEscudo3;
    InimigoEscudo *inimigoEscudo4;
    InimigoEscudo *inimigoEscudo5;
    InimigoEscudo *inimigoEscudo6;
    InimigoEscudo *inimigoEscudo7;
    InimigoEscudo *inimigoEscudo8;
    InimigoEscudo *inimigoEscudo9;
    InimigoEscudo *inimigoEscudo10;
    
    ParFigura *placaSaida;
    ObjetoSimples *placa_saida;
          
    InimigosStagio(){
        this->refem = new ParFigura("images\\Prisioneiro.bmp");
        this->caminhao = new ParFigura("images\\CaminhaoIncinerado.bmp");
        this->inimigoAtirador = new ParFigura("images\\InimigoAtirando.bmp");
        this->inimigoAtiradorParado = new ParFigura("images\\InimigoAtiradorParado.bmp");
        this->morrendo = new ParFigura("images\\InimigoMorrendo.bmp"); 
        this->incinerado = new ParFigura("images\\inimigoPegandoFogo.bmp");
        this->passaro = new ParFigura("images\\jandaia.bmp"); 
        this->figuraBala = new ParFigura("images\\balaInimigoescudo.bmp");
        this->figuraColBala = new ParFigura("images\\explosaoBala.bmp");
        this->inimigo2atirando = new ParFigura("images\\inimigo_escudo\\inimigoEscudoAtirando.bmp");
        this->inimigo2parado = new ParFigura("images\\inimigo_escudo\\inimigoEscudoParado.bmp");
        this->inimigo2tiranEsc = new ParFigura("images\\inimigo_escudo\\inimigoEscudoTirandoEscudo.bmp");
        this->inimigo2botanEsc = new ParFigura("images\\inimigo_escudo\\inimigoEscudoGuardandoEscudo.bmp");
        this->placaSaida = new ParFigura("images\\Seta.bmp");
        
        switch(stage){
                case 1:
                        this->refemCaminhando = new Refem(550,150,this->refem);        
                        this->caminhaoBand = new ObjetoSimples(797,155,this->caminhao,6,true);             
                        this->inimigo1 = new InimigoAtirador(450,100,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo2 = new InimigoAtirador(820,100,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo3 = new InimigoAtirador(1345,80,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo4 = new InimigoAtirador(1287,80,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);                                
                        this->inimigo5 = new InimigoAtirador(2060,50,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo6 = new InimigoAtirador(2570,100,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo7 = new InimigoAtirador(3600,100,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        // this->inimigo8 = new InimigoAtirador(3700,80,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo9 = new InimigoAtirador(3800,80,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        //this->inimigo10 = new InimigoAtirador(3900,50,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->passaro1 = new Passarinho(700,50,this->passaro);
                        this->passaro2 = new Passarinho(710,60,this->passaro);
                        this->passaro3 = new Passarinho(750,70,this->passaro);
                        this->passaro4 = new Passarinho(760,80,this->passaro);       
                        this->inimigoEscudo1 = new InimigoEscudo(650,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo2 = new InimigoEscudo(750,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo3 = new InimigoEscudo(800,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo4 = new InimigoEscudo(1520,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo5 = new InimigoEscudo(1820,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo6 = new InimigoEscudo(2700,80,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo7 = new InimigoEscudo(3460,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        //   this->inimigoEscudo8 = new InimigoEscudo(3550,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo9 = new InimigoEscudo(3650,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        //   this->inimigoEscudo10 = new InimigoEscudo(3750,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->placa_saida = new ObjetoSimples(4125,195,this->placaSaida,5,false);
                break;
                case 2:
                        this->refemCaminhando = new Refem(550,150,this->refem);        
                        this->caminhaoBand = new ObjetoSimples(797,155,this->caminhao,6,true);             
                        this->inimigo1 = new InimigoAtirador(450,100,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo2 = new InimigoAtirador(970,20,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo3 = new InimigoAtirador(1345,80,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo4 = new InimigoAtirador(1487,80,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);                                
                        this->inimigo5 = new InimigoAtirador(2020,50,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo6 = new InimigoAtirador(2500,30,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo7 = new InimigoAtirador(3100,30,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        // this->inimigo8 = new InimigoAtirador(3700,80,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo9 = new InimigoAtirador(3950,30,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        //this->inimigo10 = new InimigoAtirador(3900,50,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->passaro1 = new Passarinho(700,50,this->passaro);
                        this->passaro2 = new Passarinho(710,60,this->passaro);
                        this->passaro3 = new Passarinho(2950,70,this->passaro);
                        this->passaro4 = new Passarinho(2960,80,this->passaro);       
                        this->inimigoEscudo1 = new InimigoEscudo(650,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo2 = new InimigoEscudo(970,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo3 = new InimigoEscudo(800,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo4 = new InimigoEscudo(1720,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo5 = new InimigoEscudo(1820,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo6 = new InimigoEscudo(2650,120,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo7 = new InimigoEscudo(3460,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        //   this->inimigoEscudo8 = new InimigoEscudo(3550,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo9 = new InimigoEscudo(3650,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        //   this->inimigoEscudo10 = new InimigoEscudo(3750,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->placa_saida = new ObjetoSimples(4125,195,this->placaSaida,5,false);
                
                break;
                case 3:
                        this->refemCaminhando = new Refem(1460,100,this->refem);        
                        this->caminhaoBand = new ObjetoSimples(797,155,this->caminhao,6,true);             
                        this->inimigo1 = new InimigoAtirador(450,100,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo2 = new InimigoAtirador(760,30,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo3 = new InimigoAtirador(1395,50,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo4 = new InimigoAtirador(1587,50,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);                                
                        this->inimigo5 = new InimigoAtirador(2060,50,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo6 = new InimigoAtirador(2570,50,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo7 = new InimigoAtirador(3600,50,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        // this->inimigo8 = new InimigoAtirador(3700,80,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->inimigo9 = new InimigoAtirador(3800,50,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        //this->inimigo10 = new InimigoAtirador(3900,50,this->inimigoAtirador,this->inimigoAtiradorParado,this->morrendo);
                        this->passaro1 = new Passarinho(700,50,this->passaro);
                        this->passaro2 = new Passarinho(710,60,this->passaro);
                        this->passaro3 = new Passarinho(2750,70,this->passaro);
                        this->passaro4 = new Passarinho(2760,80,this->passaro);       
                        this->inimigoEscudo1 = new InimigoEscudo(650,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo2 = new InimigoEscudo(1050,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo3 = new InimigoEscudo(1350,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo4 = new InimigoEscudo(1520,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo5 = new InimigoEscudo(1820,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo6 = new InimigoEscudo(2700,80,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo7 = new InimigoEscudo(3460,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        //   this->inimigoEscudo8 = new InimigoEscudo(3550,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->inimigoEscudo9 = new InimigoEscudo(3650,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        //   this->inimigoEscudo10 = new InimigoEscudo(3750,100,inimigo2atirando,inimigo2parado,inimigo2tiranEsc,inimigo2botanEsc,this->morrendo);
                        this->placa_saida = new ObjetoSimples(4125,195,this->placaSaida,5,false);
                
                break;
        }

    }
    ~InimigosStagio(){
        delete(this->refem);
        delete(this->refemCaminhando);
        delete(this->caminhao);
        delete(this->caminhaoBand);
        delete(this->inimigoAtirador);
        delete(this->inimigoAtiradorParado);
        delete(this->morrendo);        
        delete(this->inimigo1);
        delete(this->inimigo2);
        delete(this->incinerado);
        delete(this->passaro);
        delete(this->passaro1);
        delete(this->passaro2);
        delete(this->passaro3);
        delete(this->passaro4);
        delete(this->figuraBala);
        delete(this->figuraColBala);
        delete(this->inimigo2atirando);
        delete(this->inimigo2parado);
        delete(this->inimigo2tiranEsc);
        delete(this->inimigo2botanEsc);
        delete(this->inimigoEscudo1);      
        delete(this->placaSaida);
        delete(this->placa_saida);
    }   
};
#endif
